@@ -6,6 +6,7 @@ import warnings
 import numpy as np
 import scipy as sp
 import sympy as sm
+from pydy.codegen.ode_function_generators import generate_ode_function
 
 Cython = sm.external.import_module('Cython')
 theano = sm.external.import_module('theano')
@@ -15,11 +16,48 @@ from ..ode_function_generators import (ODEFunctionGenerator,
                                        LambdifyODEFunctionGenerator,
                                        CythonODEFunctionGenerator,
                                        TheanoODEFunctionGenerator)
+
 from ...utils import PyDyImportWarning
 
 warnings.simplefilter('once', PyDyImportWarning)
 
 
+def test_cse_same_numerical_results():
+    # NOTE : This ensurses that the same results are always given for the sympy
+    # cse outputs, which seem to change every version.
+
+    if not Cython:
+        return
+
+    sys = models.n_link_pendulum_on_cart(n=5, cart_force=False,
+                                         joint_torques=False)
+
+    g_no_cse = CythonODEFunctionGenerator(
+        sys.eom_method.forcing_full,
+        sys.coordinates,
+        sys.speeds,
+        sys.constants_symbols,
+        mass_matrix=sys.eom_method.mass_matrix_full,
+        cse=False)
+    rhs_func_no_cse = g_no_cse.generate()
+
+    g_cse = CythonODEFunctionGenerator(
+        sys.eom_method.forcing_full,
+        sys.coordinates,
+        sys.speeds,
+        sys.constants_symbols,
+        mass_matrix=sys.eom_method.mass_matrix_full,
+        cse=True)
+    rhs_func_cse = g_cse.generate()
+
+    x = np.random.random(g_cse.num_coordinates + g_cse.num_speeds)
+    t = 5.125
+    p = np.random.random(g_cse.num_constants)
+
+    np.testing.assert_allclose(rhs_func_no_cse(x, t, p),
+                               rhs_func_cse(x, t, p))
+
+
 class TestODEFunctionGenerator(object):
 
     def setup(self):
@@ -113,6 +151,18 @@ class TestODEFunctionGenerator(object):
 
         assert g._solve_linear_system == solver
 
+    def test_no_constants(self):
+        sys = models.multi_mass_spring_damper()
+        constant_vals = {sm.Symbol('m0'): 1.0, sm.Symbol('c0'): 2.0, sm.Symbol('k0'): 3.0}
+
+        sym_rhs = sys.eom_method.rhs()
+
+        rhs = generate_ode_function(sym_rhs, sys.coordinates, sys.speeds, constant_vals)
+        rhs2 = generate_ode_function(sym_rhs.subs(constant_vals), sys.coordinates, sys.speeds)
+
+        assert np.array_equal(rhs(np.array([1.0, 2.0]), 0.0, constant_vals),
+                              rhs2(np.array([1.0, 2.0]), 0.0))
+
 
 class TestODEFunctionGeneratorSubclasses(object):
 
