@@ -1,22 +1,27 @@
 #!/usr/bin/env python
 
+import os
 import warnings
+import tempfile
+import shutil
 
 import numpy as np
 from numpy import testing
 import sympy as sm
-from sympy.physics.mechanics import dynamicsymbols
+import sympy.physics.mechanics as me
 from scipy.integrate import odeint
 theano = sm.external.import_module('theano')
+Cython = sm.external.import_module('Cython')
 
 from ..system import System
 from ..models import multi_mass_spring_damper, n_link_pendulum_on_cart
-from ..utils import sympy_equal_to_or_newer_than, PyDyImportWarning
+from ..utils import PyDyImportWarning, sympy_newer_than
 
 SYMPY_VERSION = sm.__version__
 
 warnings.simplefilter('once', PyDyImportWarning)
 
+
 class TestSystem():
 
     def setup(self):
@@ -44,17 +49,18 @@ class TestSystem():
         assert (sys.constants_symbols ==
                 set(sm.symbols('k0, m0, g, c0')))
         assert sys.specifieds_symbols == {self.specified_symbol}
-        assert sys.states == dynamicsymbols('x0, v0')
+        assert sys.states == me.dynamicsymbols('x0, v0')
         assert sys.evaluate_ode_function is None
         assert sys.eom_method is self.kane
         assert sys.ode_solver is odeint
         assert sys.specifieds == dict()
         assert sys.initial_conditions == dict()
         assert sys.constants == dict()
+        assert sys.times == list()
 
         # Specify a bunch of attributes during construction.
         # --------------------------------------------------
-        ic = {dynamicsymbols('x0'): 3.6, dynamicsymbols('v0'): 4.3}
+        ic = {me.dynamicsymbols('x0'): 3.6, me.dynamicsymbols('v0'): 4.3}
         sys = System(self.kane,
                      ode_solver=odeint,
                      specifieds={self.specified_symbol: np.ones(1)},
@@ -62,7 +68,7 @@ class TestSystem():
                      constants=self.constant_map)
 
         assert sys.eom_method is self.kane
-        assert list(sys.specifieds.keys()) == [dynamicsymbols('f0')]
+        assert list(sys.specifieds.keys()) == [me.dynamicsymbols('f0')]
         testing.assert_allclose(list(sys.specifieds.values()),
                                 [np.ones(1)])
         assert sys.initial_conditions.keys() == ic.keys()
@@ -82,22 +88,13 @@ class TestSystem():
                      constants=self.constant_map)
 
     def test_coordinates(self):
-        if sympy_equal_to_or_newer_than('0.7.6'):
-            assert self.sys.coordinates == self.kane.q[:]
-        else:
-            assert self.sys.coordinates == self.kane._q
+        assert self.sys.coordinates == self.kane.q[:]
 
     def test_speeds(self):
-        if sympy_equal_to_or_newer_than('0.7.6'):
-            assert self.sys.speeds == self.kane.u[:]
-        else:
-            assert self.sys.speeds == self.kane._u
+        assert self.sys.speeds == self.kane.u[:]
 
     def test_states(self):
-        if sympy_equal_to_or_newer_than('0.7.6'):
-            assert self.sys.states == self.kane.q[:] + self.kane.u[:]
-        else:
-            assert self.sys.states == self.kane._q + self.kane._u
+        assert self.sys.states == self.kane.q[:] + self.kane.u[:]
 
     def test_constants(self):
 
@@ -135,7 +132,7 @@ class TestSystem():
         testing.assert_allclose(list(sys.constants.values()), [9.3])
 
         # Putting in a non-constant key does not raise exception.
-        sys.constants[dynamicsymbols('v0')] = 9.8
+        sys.constants[me.dynamicsymbols('v0')] = 9.8
         # Then, if we integrate, we do error-checking and we get an exception.
         sys.times = [0.0, 1.0]
         with testing.assert_raises(ValueError):
@@ -144,26 +141,26 @@ class TestSystem():
         # Provide a constant that isn't actually a constant.
         # --------------------------------------------------
         with testing.assert_raises(ValueError):
-            sys.constants = {dynamicsymbols('x0'): 1.3}
+            sys.constants = {me.dynamicsymbols('x0'): 1.3}
         with testing.assert_raises(ValueError):
-            sys.constants = {dynamicsymbols('f0'): 1.8}
+            sys.constants = {me.dynamicsymbols('f0'): 1.8}
 
     def test_specifieds(self):
 
         sys = System(self.kane)
         assert sys.specifieds == dict()
-        sys.specifieds = {dynamicsymbols('f0'): 5.9}
-        assert list(sys.specifieds.keys()) == [dynamicsymbols('f0')]
+        sys.specifieds = {me.dynamicsymbols('f0'): 5.9}
+        assert list(sys.specifieds.keys()) == [me.dynamicsymbols('f0')]
         testing.assert_allclose(list(sys.specifieds.values()), [5.9])
 
         # Using the property as a dict.
         # -----------------------------
         # Modifying the dict directly does change the dict.
-        sys.specifieds[dynamicsymbols('f0')] = 5.1
-        assert list(sys.specifieds.keys()) == [dynamicsymbols('f0')]
+        sys.specifieds[me.dynamicsymbols('f0')] = 5.1
+        assert list(sys.specifieds.keys()) == [me.dynamicsymbols('f0')]
         testing.assert_allclose(list(sys.specifieds.values()), [5.1])
         # Putting in a non-specified key does not raise exception.
-        sys.specifieds[dynamicsymbols('v0')] = 3.5
+        sys.specifieds[me.dynamicsymbols('v0')] = 3.5
         # Then, if we integrate, we do error-checking and we get an exception.
         sys.times = [0.0, 1.0]
         with testing.assert_raises(ValueError):
@@ -171,7 +168,7 @@ class TestSystem():
 
         sys = System(self.kane)
         # Putting in a value of the wrong length does not raise exception.
-        sys.specifieds[dynamicsymbols('f0')] = 3.1 * np.ones(2)
+        sys.specifieds[me.dynamicsymbols('f0')] = 3.1 * np.ones(2)
         # Then, if we integrate, we do error-checking and we get an exception.
         # TODO actually, this does not seem to throw an exception.
         # TODO with testing.assert_raises(ValueError):
@@ -184,7 +181,7 @@ class TestSystem():
         with testing.assert_raises(ValueError):
             sys.specifieds = {sm.symbols('m0'): 5.4}
         with testing.assert_raises(ValueError):
-            sys.specifieds = {dynamicsymbols('x0'): 5.1}
+            sys.specifieds = {me.dynamicsymbols('x0'): 5.1}
 
         # Complex error-checking when using property as a dict.
         # -----------------------------------------------------
@@ -238,7 +235,7 @@ class TestSystem():
             sys.specifieds = {'symbols': [sm.symbols('T2, T2')],
                               'values': [1, 2]}
         with testing.assert_raises(ValueError):
-            sys.specifieds = {'symbols': [dynamicsymbols('T2')],
+            sys.specifieds = {'symbols': [me.dynamicsymbols('T2')],
                               'values': [1.0]}
 
         # Reordering causes issues!
@@ -255,11 +252,29 @@ class TestSystem():
 
         # Test with no specifieds.
         sys = multi_mass_spring_damper(1, apply_gravity=True)
-        sys.initial_conditions = {dynamicsymbols('x0'): 0.1,
-                                  dynamicsymbols('v0'): -1.0}
+        sys.initial_conditions = {me.dynamicsymbols('x0'): 0.1,
+                                  me.dynamicsymbols('v0'): -1.0}
         sys.times = times
         sys.integrate()
 
+    def test_times(self):
+        times1 = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
+        times2 = [0, -2, 7, 3, -5]
+        times3 = [1, 2, 7, 4, 5]
+        times4 = 4
+
+        sys = System(self.kane, times=times1)
+        testing.assert_allclose(sys.times, times1)
+
+        with testing.assert_raises(ValueError):
+            sys.times = times2
+
+        with testing.assert_raises(ValueError):
+            sys.times = times3
+
+        with testing.assert_raises(TypeError):
+            sys.times = times4
+
     def test_ode_solver(self):
 
         assert self.sys.ode_solver == odeint
@@ -274,7 +289,7 @@ class TestSystem():
     def test_initial_conditions(self):
 
         # Partially provided ic's.
-        ic = {dynamicsymbols('v0'): 6.1}
+        ic = {me.dynamicsymbols('v0'): 6.1}
 
         # Using the constructor.
         # ----------------------
@@ -295,8 +310,8 @@ class TestSystem():
         # -----------------------------
         # Modifying hte dict directly does change the dict.
         sys = System(self.kane, times=[0.0, 1.0])
-        sys.initial_conditions[dynamicsymbols('x0')] = 5.8
-        assert list(sys.initial_conditions.keys()) == [dynamicsymbols('x0')]
+        sys.initial_conditions[me.dynamicsymbols('x0')] = 5.8
+        assert list(sys.initial_conditions.keys()) == [me.dynamicsymbols('x0')]
         testing.assert_allclose(list(sys.initial_conditions.values()), [5.8])
         # Putting in a non-state key does not raise exception.
         sys.initial_conditions[sm.symbols('m0')] = 7.9
@@ -367,7 +382,7 @@ class TestSystem():
         # -----------------------------------------
         constants_dict = dict(zip(sm.symbols('m0, k0, c0, g'),
                                   [1.0, 1.0, 1.0, 1.0]))
-        specified_dict = {dynamicsymbols('f0'): 0.0}
+        specified_dict = {me.dynamicsymbols('f0'): 0.0}
         x_03 = sys.ode_solver(sys.evaluate_ode_function, [0, 0], sys.times,
                               args=(specified_dict, constants_dict))
         testing.assert_allclose(x_02, x_03)
@@ -377,7 +392,7 @@ class TestSystem():
         sys = System(self.kane, times=times)
         # I know that this is the order of the states.
         x0 = [5.1, 3.7]
-        ic = {dynamicsymbols('x0'): x0[0], dynamicsymbols('v0'): x0[1]}
+        ic = {me.dynamicsymbols('x0'): x0[0], me.dynamicsymbols('v0'): x0[1]}
         sys.initial_conditions = ic
         x_04 = sys.integrate()
         x_05 = sys.ode_solver(
@@ -403,3 +418,71 @@ class TestSystem():
         sys = System(self.kane, times=times)
         with testing.assert_raises(NotImplementedError):
             sys.generate_ode_function(generator='made-up')
+
+        # Test pass kwargs to the generators.
+        if Cython:
+            self.tempdirpath = tempfile.mkdtemp()
+            prefix = 'my_test_file'
+            self.sys.generate_ode_function(generator='cython',
+                                           prefix=prefix,
+                                           tmp_dir=self.tempdirpath)
+            assert [True for f in os.listdir(self.tempdirpath)
+                    if f.startswith(prefix)]
+        else:
+            warnings.warn("Cython was not found so the related tests are being"
+                          " skipped.", PyDyImportWarning)
+    def cleanup(self):
+        shutil.rmtree(self.tempdirpath)
+
+
+def test_specifying_coordinate_issue_339():
+    """This test ensures that you can use derivatives as specified values."""
+
+    # beta will be a specified angle
+    beta = me.dynamicsymbols('beta')
+    q1, q2, q3, q4 = me.dynamicsymbols('q1, q2, q3, q4')
+    u1, u2, u3, u4 = me.dynamicsymbols('u1, u2, u3, u4')
+
+    N = me.ReferenceFrame('N')
+    A = N.orientnew('A', 'Axis', (q1, N.x))
+    B = A.orientnew('B', 'Axis', (beta, A.y))
+
+    No = me.Point('No')
+    Ao = No.locatenew('Ao', q2 * N.x + q3 * N.y + q4 * N.z)
+    Bo = Ao.locatenew('Bo', 10 * A.x + 10 * A.y + 10 * A.z)
+
+    A.set_ang_vel(N, u1 * N.x)
+    B.ang_vel_in(N)  # compute it automatically
+
+    No.set_vel(N, 0)
+    Ao.set_vel(N, u2 * N.x + u3 * N.y + u4 * N.z)
+    Bo.v2pt_theory(Ao, N, B)
+
+    body_A = me.RigidBody('A', Ao, A, 1.0, (me.inertia(A, 1, 2, 3), Ao))
+    body_B = me.RigidBody('B', Bo, B, 1.0, (me.inertia(A, 3, 2, 1), Bo))
+
+    bodies = [body_A, body_B]
+    # TODO : This should be able to be simple an empty iterable.
+    loads = [(No, 0 * N.x)]
+
+    kdes = [u1 - q1.diff(),
+            u2 - q2.diff(),
+            u3 - q3.diff(),
+            u4 - q4.diff()]
+
+    kane = me.KanesMethod(N, q_ind=[q1, q2, q3, q4],
+                          u_ind=[u1, u2, u3, u4], kd_eqs=kdes)
+
+    if sympy_newer_than('1.0'):
+        fr, frstar = kane.kanes_equations(bodies, loads)
+    else:
+        fr, frstar = kane.kanes_equations(loads, bodies)
+
+    sys = System(kane)
+
+    sys.specifieds = {(beta, beta.diff(), beta.diff().diff()):
+                      lambda x, t: np.array([1.0, 1.0, 1.0])}
+
+    sys.times = np.linspace(0, 10, 20)
+
+    sys.integrate()
